# tethysdash-instance-template

The contents of this directory is used as a template to facilitate
setting up a new integrated TethysDash system.
Only requirements on the target machine are
[Docker Engine](https://docs.docker.com/engine/installation/)
and [Docker Compose](https://docs.docker.com/compose/install/).

With this template the user can focus on the needed configuration
and let Docker take care of pulling the service images and launching
the TethysDash system.

## Using the template

Note: The main documentation page for TethysDash installation and configuration using Docker is
[https://docs.mbari.org/tethysdash/install/docker/](https://docs.mbari.org/tethysdash/install/docker/),
which explains how to use the template in more detail.

In a nutshell, the steps for the end-user to use the template are as follows.

### Get the template

Get the latest `tethysdash-instance-template.tgz` as indicated in the documentation.
Then:

    mkdir tethysdash
    cd    tethysdash
    tar xf path/to/downloaded/tethysdash-instance-template.tgz

The expanded directory tree should look like this:

        .
        ├── README.md
        ├── setenv.sh
        ├── config
        │   ├── TethysDash.conf
        │   ├── miscLinks.json
        │   ├── tileLayers.json
        │   └── stations.json
        └── docker-compose.yml

### Environment variables

`setenv.sh` can be used to define a number of environment variables
that are used in later steps:

- Edit `setenv.sh` to review and adjust the variables as needed.
- On the command line, prior to launching the system,
  "source" `setenv.sh` to expose the variables to the
  environment: `$ source setenv.sh`

### Configuration

- Edit `config/TethysDash.conf`, which is the master configuration for your instance.
  Various entries in this file rely on environment variables defined
  as indicated above.

- Optionally, edit `config/miscLinks.json` as desired.
  This file indicates links to be included in the main dropdown menu in the Dash UI.
  The contents of this file should be a JSON object containing a `miscLinks` member with a list
  of objects, each with `href` and `text` string members.

- Optionally, edit `config/tileLayers.json`.
  This file indicates tile layers that can be included on the map in the Dash UI.
  The contents of this file should be a JSON object containing a `tileLayers` member with a list
  of objects:

        {
          "tileLayers": [
            {
              "name": "<name to be shown>",
              [ "wms": true, ]
              [ "legendurl": "https://...", ]
              "urlTemplate": "https://...",
              "options" : {
                "attribution": "...",
                "tms": true,
                ...
              }
            },
          ]
        }

    For each given layer, the given information will be passed to the
    [Leaflet](https://leafletjs.com/) library used by the Dash.
    In concrete, the Dash will use a
    [TileLayer.WMS](https://leafletjs.com/reference-1.6.0.html#tilelayer-wms)
    if `"wms": true` is given, or
    [TileLayer](https://leafletjs.com/reference-1.6.0.html#tilelayer)
    otherwise. The `"options"` object is passed directly as given.
    The optional `"legendurl"` entry is used by the Dash to show a tooltip for the entry.

- Optionally, edit `config/stations.json`.
  This file indicates the set of "stations" that can be included on the map in the Dash UI.
  The contents of this file should be a JSON object containing a `stations` member with a list
  of objects, each with `label`, `lat`, and `lon` members.

### Launching

`docker-compose.yml` specifies the services comprising the TethysDash system.
No changes are typically needed in this file unless otherwise
indicated in TethysDash documentation, release notes, or other communications.

Launch the TethysDash system:

      $ docker login
      $ source setenv.sh
      $ docker-compose up -d
